#include "new_widget.h"

#define PREFERRED_HEIGHT	150
#define PREFERRED_WIDTH		150

struct _GtkNewWidgetPrivate
{
	char *empty;
};

static void
	gtk_new_widget_get_preferred_width(GtkWidget*, gint*, gint*),
	gtk_new_widget_get_preferred_height(GtkWidget*, gint*, gint*),
	gtk_new_widget_finalize(GObject*),
	new_widget_widget_get_preferred_width_for_height(GtkWidget*, gint , gint*, gint *);

static gboolean
	gtk_new_widget_draw(GtkWidget*, cairo_t*);


G_DEFINE_TYPE(GtkNewWidget, gtk_new_widget, GTK_TYPE_RANGE)

static void gtk_new_widget_class_init(GtkNewWidgetClass *class)
{
	GObjectClass *gobject_class = G_OBJECT_CLASS(class);
	GtkWidgetClass *widget_class = (GtkWidgetClass*)class;

	gobject_class->finalize = gtk_new_widget_finalize;

	widget_class->draw = gtk_new_widget_draw;
	widget_class->get_preferred_width = gtk_new_widget_get_preferred_width;
	widget_class->get_preferred_height = gtk_new_widget_get_preferred_height;// new_widget_widget_get_preferred_height
	widget_class->get_preferred_width_for_height = new_widget_widget_get_preferred_width_for_height;
}

static void gtk_new_widget_init(GtkNewWidget *new_widget)
{
	new_widget->priv = calloc(1, sizeof(GtkNewWidgetPrivate));
	gtk_widget_set_size_request(GTK_WIDGET(new_widget), PREFERRED_WIDTH, PREFERRED_HEIGHT);
}

static void gtk_new_widget_finalize(GObject *object)
{
	G_OBJECT_CLASS(gtk_new_widget_parent_class)->finalize(object);
}

static void gtk_new_widget_get_preferred_width(GtkWidget *widget, gint *minimum, gint *natural)
{
	*minimum = MAX(PREFERRED_WIDTH, *minimum);
	*natural = MAX(PREFERRED_WIDTH, *natural);
}

static void gtk_new_widget_get_preferred_height(GtkWidget *widget, gint *minimum, gint *natural)
{
	*minimum = MAX(PREFERRED_HEIGHT, *minimum);
	*natural = MAX(PREFERRED_HEIGHT, *natural);
}

static void new_widget_widget_get_preferred_width_for_height(GtkWidget *widget, gint for_height, gint *min_width, gint *nat_width)
{
	GTK_WIDGET_GET_CLASS(widget)->get_preferred_width(widget, min_width, nat_width);
}

GtkWidget *gtk_new_widget_new()
{
	return g_object_new(GTK_TYPE_NEW_WIDGET, /*"adjustment", adjustment,*/ NULL);
}

static gboolean gtk_new_widget_draw(GtkWidget *widget, cairo_t *cr)
{
	gint originX, originY;

#ifdef USE_MATRIX
	cairo_matrix_t identityMatrix;
	cairo_matrix_init_identity(&identityMatrix);
	cairo_set_matrix(cr, &identityMatrix);
#endif

	originX = gtk_widget_get_allocated_width(widget) / 2;
	originY =  gtk_widget_get_allocated_height(widget) / 2;


	cairo_set_source_rgb(cr, 0.0, 0.0, 0.0);
	cairo_new_sub_path(cr);
	cairo_arc(cr, originX, originY, 75.0, 0.0, 2.0 * M_PI);
	cairo_close_path(cr);
	cairo_stroke_preserve(cr);

	GTK_WIDGET_CLASS(gtk_new_widget_parent_class)->draw(widget, cr);

	return(FALSE);
}
